gchecky.model.carrier_calculated_shipping_option_t

Package gchecky :: Module model :: Class carrier_calculated_shipping_option_t |
[hide private]
[frames] | no frames]

# Class carrier_calculated_shipping_option_t

source code

    object --+
             |
     gxml.Node --+
                 |
                carrier_calculated_shipping_option_t

Nested Classes | [hide private]
Inherited from `gxml.Node`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Node`: `__eq__`, `__init__`, `__neq__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| price = `Node:PATH(price):REQ:{ price_t }`
| shipping_company = `String:PATH(shipping-company):REQ:EMPTY:VAL`...``
| carrier_pickup = `String:PATH(carrier-pickup):OPT:EMPTY:DEF(DRO`...``
| shipping_type = `String:PATH(shipping-type):REQ:EMPTY`
| additional_fixed_charge = `Node:PATH(additional-fixed-charge):O`...``
| additional_variable_charge_percent = `Double:PATH(additional-va`...``
| _fields = ``{``'``additional_fixed_charge``'``:` Node:PATH(additional-fix`...`` list of meta-Fields of this class.

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### shipping_company Value:
      String:PATH(shipping-company):REQ:EMPTY:VALS("FedEx","UPS","USPS")

  ### carrier_pickup Value:
      String:PATH(carrier-pickup):OPT:EMPTY:DEF(DROP_OFF):VALS("REGULAR_PICK
      UP","SPECIAL_PICKUP","DROP_OFF")

  ### additional_fixed_charge Value:
      Node:PATH(additional-fixed-charge):OPT:{ price_t }

  ### additional_variable_charge_percent Value:
      Double:PATH(additional-variable-charge-percent):OPT

  ### _fields list of meta-Fields of this class. Value:
      {'additional_fixed_charge': Node:PATH(additional-fixed-charge):OPT:{ p
      rice_t },
       'additional_variable_charge_percent': Double:PATH(additional-variable
      -charge-percent):OPT,
       'carrier_pickup': String:PATH(carrier-pickup):OPT:EMPTY:DEF(DROP_OFF)
      :VALS("REGULAR_PICKUP","SPECIAL_PICKUP","DROP_OFF"),
       'price': Node:PATH(price):REQ:{ price_t },
       'shipping_company': String:PATH(shipping-company):REQ:EMPTY:VALS("Fed
      ...